@@ -3,9 +3,9 @@
 try:
     import django.test
 except ImportError as error:
-    print(error.__class__.__name__ + ": " + error.message)
+    print(error.__class__.__name__ + ": " + error)
 
-from unittest.mock import Mock, patch
+from unittest.mock import patch
 
 
 class ETLTest(django.test.TestCase):
@@ -13,10 +13,10 @@ class ETLTest(django.test.TestCase):
     @classmethod
     def setUpClass(cls):
         super(ETLTest, cls).setUpClass()
-        cls.mock_get_patcher = patch('opdmetl.extractors.requests.get')
+        cls.mock_get_patcher = patch('ooetl.extractors.requests.get')
         cls.mock_get = cls.mock_get_patcher.start()
 
     @classmethod
     def tearDownClass(cls):
         cls.mock_get_patcher.stop()
-        super(ETLTest, cls).tearDownClass()
\ No newline at end of file
+        super(ETLTest, cls).tearDownClass()
